cmoncrawl.processor.pipeline.extractor.BaseExtractor.filter\_soup
=================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: BaseExtractor.filter_soup